/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.search.test.util;

import com.liferay.portal.kernel.search.Document;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import org.junit.Assert;

/**
 * @author André de Oliveira
 */
public class DocumentsAssert {

	public static void assertCount(
		String message, Document[] documents, String field, int expectedCount) {

		if (documents.length == expectedCount) {
			return;
		}

		List<String> actualValues = _getValues(field, documents);

		Assert.assertEquals(
			message + "->" + actualValues, expectedCount, documents.length);
	}

	public static void assertValues(
		String message, Document[] documents, String field,
		List<String> expectedValues) {

		List<String> actualValues = _getValues(field, documents);

		Assert.assertEquals(
			message + "->" + actualValues, expectedValues.toString(),
			actualValues.toString());
	}

	public static void assertValuesIgnoreRelevance(
		String message, Document[] documents, String field,
		Collection<String> expectedValues) {

		List<String> actualValues = _getValues(field, documents);

		Assert.assertEquals(
			message + "->" + actualValues, _sort(expectedValues),
			_sort(actualValues));
	}

	private static List<String> _getValues(
		String field, Document... documents) {

		Stream<Document> documentsStream = Stream.of(documents);

		Stream<String> valuesStream = documentsStream.map(
			document -> document.get(field));

		return valuesStream.collect(Collectors.toList());
	}

	private static String _sort(Collection<String> collection) {
		List<String> list = new ArrayList<>(collection);

		Collections.sort(list);

		return list.toString();
	}

}